#
# spec file for package rubygem-gem2rpm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  gem2rpm_bootstrap
%if 0%{?suse_version} && 0%{?suse_version} < 1315
%bcond_with     ruby18
%bcond_with     ruby19
%bcond_with     ruby20
%endif
%bcond_with     ruby21
%if ! (0%{?suse_version} == 1315)
%bcond_with     ruby22
%bcond_with     ruby23
%bcond_with     ruby24
%endif
%bcond_with     ruby25
%if ! (0%{?suse_version} == 1550)
%bcond_with     ruby26
%endif
%bcond_with     ruby27
%bcond_with     ruby30
%bcond_with     ruby31
%bcond_with     ruby32
%bcond_with     ruby33
%bcond_with     ruby34
%bcond_with     rubinius25

Name:           rubygem-gem2rpm
Version:        0.10.1
Release:        26.0.4.1.sr20250101
%define mod_name gem2rpm
%define mod_full_name %{mod_name}-%{version}
%define mod_branch -%{version}
%define mod_weight 1001
BuildRequires:  %{ruby}
BuildRequires:  ruby-macros >= 5
%if %{with gem2rpm_bootstrap}
#!BuildIgnore:  rubygem(gem2rpm) rubygem(ruby:2.1.0:gem2rpm) rubygem(ruby:2.2.0:gem2rpm) rubygem(rbx:2.2:gem2rpm)
%else
BuildRequires:  %{rubygem gem2rpm}
%endif
BuildRequires:  ruby-common >= 3.2
BuildRequires:  update-alternatives
URL:            https://github.com/lutter/gem2rpm/
Source:         http://rubygems.org/gems/%{mod_full_name}.gem
Source1:        update-suse-patch.sh
Source2:        gem2rpm-opensuse
Source3:        series
Patch01:        suse.patch
Summary:        Generate rpm specfiles from gems
License:        GPL-2.0-or-later
Group:          Development/Languages/Ruby

%description
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%prep
%gem_unpack
%autopatch -p1

%build
perl -p -i -e 's|("templates/opensuse.spec.erb".freeze)|$1, "templates/gem_packages.spec.erb".freeze|g' *gemspec
%gem_build

%install
%gem_install -f -N --symlink-binaries --doc-files="AUTHORS LICENSE README"
for i in %{buildroot}%{_docdir}/*rubygem-gem2rpm*/ ; do
  install -m 0644 gem2rpm-%{version}/gem2rpm.yml.documentation $i/gem2rpm.yml
done

%if %{with gem2rpm_bootstrap}
%if %{with ruby21}
%package -n ruby2.1-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby2.1-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby2.1-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby2.1-rubygem-gem2rpm = %{version}

%description -n ruby2.1-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby2.1-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby2.1-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby2.1-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby2.1 gem2rpm.ruby2.1 %{_bindir}/gem2rpm.ruby2.1-%{version} %{mod_weight}

%preun -n ruby2.1-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby2.1-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby2.1-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby2.1  %{_bindir}/gem2rpm.ruby2.1-%{version}
fi

%files -n ruby2.1-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby2.1-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby2.1-%{version}
%ghost %{_bindir}/gem2rpm.ruby2.1
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby2.1
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/2.1.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/2.1.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/2.1.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby2.1-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/2.1.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby18}
%package -n ruby1.8-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby1.8-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby1.8-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby1.8-rubygem-gem2rpm = %{version}

%description -n ruby1.8-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby1.8-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby1.8-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby1.8-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby1.8 gem2rpm.ruby1.8 %{_bindir}/gem2rpm.ruby1.8-%{version} %{mod_weight}

%preun -n ruby1.8-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby1.8-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby1.8-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby1.8  %{_bindir}/gem2rpm.ruby1.8-%{version}
fi

%files -n ruby1.8-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby1.8-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby1.8-%{version}
%ghost %{_bindir}/gem2rpm.ruby1.8
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby1.8
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/1.8/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/1.8/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/1.8/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby1.8-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/1.8/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby19}
%package -n ruby1.9-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby1.9-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby1.9-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby1.9-rubygem-gem2rpm = %{version}

%description -n ruby1.9-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby1.9-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby1.9-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby1.9-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby1.9 gem2rpm.ruby1.9 %{_bindir}/gem2rpm.ruby1.9-%{version} %{mod_weight}

%preun -n ruby1.9-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby1.9-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby1.9-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby1.9  %{_bindir}/gem2rpm.ruby1.9-%{version}
fi

%files -n ruby1.9-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby1.9-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby1.9-%{version}
%ghost %{_bindir}/gem2rpm.ruby1.9
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby1.9
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/1.9.1/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/1.9.1/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/1.9.1/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby1.9-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/1.9.1/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby20}
%package -n ruby2.0-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby2.0-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby2.0-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby2.0-rubygem-gem2rpm = %{version}

%description -n ruby2.0-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby2.0-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby2.0-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby2.0-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby2.0 gem2rpm.ruby2.0 %{_bindir}/gem2rpm.ruby2.0-%{version} %{mod_weight}

%preun -n ruby2.0-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby2.0-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby2.0-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby2.0  %{_bindir}/gem2rpm.ruby2.0-%{version}
fi

%files -n ruby2.0-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby2.0-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby2.0-%{version}
%ghost %{_bindir}/gem2rpm.ruby2.0
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby2.0
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/2.0.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/2.0.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/2.0.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby2.0-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/2.0.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby22}
%package -n ruby2.2-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby2.2-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby2.2-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby2.2-rubygem-gem2rpm = %{version}

%description -n ruby2.2-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby2.2-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby2.2-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby2.2-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby2.2 gem2rpm.ruby2.2 %{_bindir}/gem2rpm.ruby2.2-%{version} %{mod_weight}

%preun -n ruby2.2-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby2.2-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby2.2-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby2.2  %{_bindir}/gem2rpm.ruby2.2-%{version}
fi

%files -n ruby2.2-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby2.2-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby2.2-%{version}
%ghost %{_bindir}/gem2rpm.ruby2.2
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby2.2
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/2.2.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/2.2.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/2.2.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby2.2-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/2.2.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby23}
%package -n ruby2.3-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby2.3-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby2.3-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby2.3-rubygem-gem2rpm = %{version}

%description -n ruby2.3-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby2.3-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby2.3-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby2.3-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby2.3 gem2rpm.ruby2.3 %{_bindir}/gem2rpm.ruby2.3-%{version} %{mod_weight}

%preun -n ruby2.3-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby2.3-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby2.3-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby2.3  %{_bindir}/gem2rpm.ruby2.3-%{version}
fi

%files -n ruby2.3-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby2.3-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby2.3-%{version}
%ghost %{_bindir}/gem2rpm.ruby2.3
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby2.3
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/2.3.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/2.3.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/2.3.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby2.3-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/2.3.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby24}
%package -n ruby2.4-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby2.4-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby2.4-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby2.4-rubygem-gem2rpm = %{version}

%description -n ruby2.4-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby2.4-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby2.4-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby2.4-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby2.4 gem2rpm.ruby2.4 %{_bindir}/gem2rpm.ruby2.4-%{version} %{mod_weight}

%preun -n ruby2.4-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby2.4-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby2.4-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby2.4  %{_bindir}/gem2rpm.ruby2.4-%{version}
fi

%files -n ruby2.4-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby2.4-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby2.4-%{version}
%ghost %{_bindir}/gem2rpm.ruby2.4
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby2.4
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/2.4.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/2.4.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/2.4.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby2.4-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/2.4.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby25}
%package -n ruby2.5-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby2.5-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby2.5-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby2.5-rubygem-gem2rpm = %{version}

%description -n ruby2.5-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby2.5-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby2.5-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby2.5-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby2.5 gem2rpm.ruby2.5 %{_bindir}/gem2rpm.ruby2.5-%{version} %{mod_weight}

%preun -n ruby2.5-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby2.5-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby2.5-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby2.5  %{_bindir}/gem2rpm.ruby2.5-%{version}
fi

%files -n ruby2.5-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby2.5-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby2.5-%{version}
%ghost %{_bindir}/gem2rpm.ruby2.5
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby2.5
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/2.5.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/2.5.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/2.5.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby2.5-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/2.5.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby26}
%package -n ruby2.6-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby2.6-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby2.6-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby2.6-rubygem-gem2rpm = %{version}

%description -n ruby2.6-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby2.6-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby2.6-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby2.6-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby2.6 gem2rpm.ruby2.6 %{_bindir}/gem2rpm.ruby2.6-%{version} %{mod_weight}

%preun -n ruby2.6-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby2.6-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby2.6-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby2.6  %{_bindir}/gem2rpm.ruby2.6-%{version}
fi

%files -n ruby2.6-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby2.6-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby2.6-%{version}
%ghost %{_bindir}/gem2rpm.ruby2.6
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby2.6
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/2.6.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/2.6.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/2.6.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby2.6-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/2.6.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby27}
%package -n ruby2.7-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby2.7-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby2.7-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby2.7-rubygem-gem2rpm = %{version}

%description -n ruby2.7-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby2.7-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby2.7-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby2.7-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby2.7 gem2rpm.ruby2.7 %{_bindir}/gem2rpm.ruby2.7-%{version} %{mod_weight}

%preun -n ruby2.7-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby2.7-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby2.7-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby2.7  %{_bindir}/gem2rpm.ruby2.7-%{version}
fi

%files -n ruby2.7-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby2.7-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby2.7-%{version}
%ghost %{_bindir}/gem2rpm.ruby2.7
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby2.7
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/2.7.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/2.7.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/2.7.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby2.7-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/2.7.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby30}
%package -n ruby3.0-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby3.0-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby3.0-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby3.0-rubygem-gem2rpm = %{version}

%description -n ruby3.0-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby3.0-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby3.0-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby3.0-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby3.0 gem2rpm.ruby3.0 %{_bindir}/gem2rpm.ruby3.0-%{version} %{mod_weight}

%preun -n ruby3.0-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby3.0-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby3.0-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby3.0  %{_bindir}/gem2rpm.ruby3.0-%{version}
fi

%files -n ruby3.0-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby3.0-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby3.0-%{version}
%ghost %{_bindir}/gem2rpm.ruby3.0
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby3.0
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/3.0.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/3.0.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/3.0.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby3.0-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/3.0.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby31}
%package -n ruby3.1-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby3.1-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby3.1-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby3.1-rubygem-gem2rpm = %{version}

%description -n ruby3.1-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby3.1-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby3.1-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby3.1-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby3.1 gem2rpm.ruby3.1 %{_bindir}/gem2rpm.ruby3.1-%{version} %{mod_weight}

%preun -n ruby3.1-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby3.1-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby3.1-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby3.1  %{_bindir}/gem2rpm.ruby3.1-%{version}
fi

%files -n ruby3.1-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby3.1-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby3.1-%{version}
%ghost %{_bindir}/gem2rpm.ruby3.1
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby3.1
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/3.1.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/3.1.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/3.1.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby3.1-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/3.1.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby32}
%package -n ruby3.2-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby3.2-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby3.2-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby3.2-rubygem-gem2rpm = %{version}

%description -n ruby3.2-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby3.2-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby3.2-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby3.2-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby3.2 gem2rpm.ruby3.2 %{_bindir}/gem2rpm.ruby3.2-%{version} %{mod_weight}

%preun -n ruby3.2-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby3.2-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby3.2-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby3.2  %{_bindir}/gem2rpm.ruby3.2-%{version}
fi

%files -n ruby3.2-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby3.2-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby3.2-%{version}
%ghost %{_bindir}/gem2rpm.ruby3.2
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby3.2
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/3.2.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/3.2.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/3.2.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby3.2-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/3.2.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby33}
%package -n ruby3.3-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby3.3-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby3.3-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby3.3-rubygem-gem2rpm = %{version}

%description -n ruby3.3-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby3.3-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby3.3-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby3.3-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby3.3 gem2rpm.ruby3.3 %{_bindir}/gem2rpm.ruby3.3-%{version} %{mod_weight}

%preun -n ruby3.3-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby3.3-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby3.3-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby3.3  %{_bindir}/gem2rpm.ruby3.3-%{version}
fi

%files -n ruby3.3-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby3.3-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby3.3-%{version}
%ghost %{_bindir}/gem2rpm.ruby3.3
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby3.3
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/3.3.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/3.3.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/3.3.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby3.3-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/3.3.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with ruby34}
%package -n ruby3.4-rubygem-gem2rpm
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n ruby3.4-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible

%package -n ruby3.4-rubygem-gem2rpm-doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       ruby3.4-rubygem-gem2rpm = %{version}

%description -n ruby3.4-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n ruby3.4-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm         gem2rpm         %{_bindir}/gem2rpm.ruby3.4-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm-%{version}   gem2rpm-%{version}   %{_bindir}/gem2rpm.ruby3.4-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    %{_bindir}/gem2rpm.ruby3.4 gem2rpm.ruby3.4 %{_bindir}/gem2rpm.ruby3.4-%{version} %{mod_weight}

%preun -n ruby3.4-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm          %{_bindir}/gem2rpm.ruby3.4-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version}    %{_bindir}/gem2rpm.ruby3.4-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.ruby3.4  %{_bindir}/gem2rpm.ruby3.4-%{version}
fi

%files -n ruby3.4-rubygem-gem2rpm
%defattr(-,root,root,-)
%{_docdir}/ruby3.4-rubygem-gem2rpm
#{_bindir}/gem2rpm-opensuse
%{_bindir}/gem2rpm.ruby3.4-%{version}
%ghost %{_bindir}/gem2rpm.ruby3.4
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm
%ghost %{_sysconfdir}/alternatives/gem2rpm.ruby3.4
%ghost %{_sysconfdir}/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/ruby/gems/3.4.0/cache/gem2rpm-%{version}.gem
%{_libdir}/ruby/gems/3.4.0/gems/gem2rpm-%{version}
%{_libdir}/ruby/gems/3.4.0/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n ruby3.4-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/3.4.0/doc/gem2rpm-%{version}
%endif
%endif

%if %{with rubinius25}
%package -n rbx2.5-rubygem-gem2rpm
# MANUAL
# /MANUAL
Summary:        Generate rpm specfiles from gems
Group:          Development/Languages/Ruby
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description -n rbx2.5-rubygem-gem2rpm
Generate source rpms and rpm spec files from a Ruby Gem.
The spec file tries to follow the gem as closely as possible.

%package -n rbx2.5-rubygem-gem2rpm-doc
Summary:        RDoc documentation for gem2rpm
Group:          Development/Languages/Ruby
Requires:       rbx2.5-rubygem-gem2rpm = %{version}

%description -n rbx2.5-rubygem-gem2rpm-doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%post -n rbx2.5-rubygem-gem2rpm
/usr/sbin/update-alternatives --install \
    /usr/bin/gem2rpm                      gem2rpm /usr/bin/gem2rpm.rbx2.5-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    /usr/bin/gem2rpm-%{version} gem2rpm-%{version} /usr/bin/gem2rpm.rbx2.5-%{version} %{mod_weight}
/usr/sbin/update-alternatives --install \
    /usr/bin/gem2rpm.rbx2.5     gem2rpm.rbx2.5 /usr/bin/gem2rpm.rbx2.5-%{version} %{mod_weight}

%preun -n rbx2.5-rubygem-gem2rpm
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove gem2rpm /usr/bin/gem2rpm.rbx2.5-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm-%{version} /usr/bin/gem2rpm.rbx2.5-%{version}
    /usr/sbin/update-alternatives --remove gem2rpm.rbx2.5 /usr/bin/gem2rpm.rbx2.5-%{version}
fi

%files -n rbx2.5-rubygem-gem2rpm
%defattr(-,root,root,-)
# MANUAL
# /MANUAL
/usr/share/doc/packages/rbx2.5-rubygem-gem2rpm
%{_bindir}/gem2rpm.rbx2.5-%{version}
%ghost %{_bindir}/gem2rpm.rbx2.5
%ghost %{_bindir}/gem2rpm-%{version}
%ghost %{_bindir}/gem2rpm
%ghost /etc/alternatives/gem2rpm
%ghost /etc/alternatives/gem2rpm.rbx2.5
%ghost /etc/alternatives/gem2rpm-%{version}
# cache file
%{_libdir}/rubinius/gems/2.5/cache/gem2rpm-%{version}.gem
%{_libdir}/rubinius/gems/2.5/gems/gem2rpm-%{version}
%{_libdir}/rubinius/gems/2.5/specifications/gem2rpm-%{version}.gemspec

%if %{with docs}
%files -n rbx2.5-rubygem-gem2rpm-doc
%defattr(-,root,root,-)
%doc %{_libdir}/rubinius/gems/2.5/doc/gem2rpm-%{version}
%endif
%endif
%else
%gem_packages
%endif

%changelog
* Wed Jan 29 2025 Marcus Rueckert <mrueckert@suse.de>
- add new gem2rpm.yml setting to have the runtime deps as
  buildrequires:
  :runtime_deps_as_buildrequires: true
  disabled by default
  implements https://github.com/openSUSE/gem2rpm/issues/20
* Fri Dec 27 2024 Marcus Rueckert <mrueckert@suse.de>
- update filelist for the final 3.4.0 api_version
* Fri Dec 13 2024 Marcus Rueckert <mrueckert@suse.de>
- Fix filelist for 3.4.0
* Thu Dec 12 2024 Marcus Rueckert <mrueckert@suse.de>
- enable ruby3.4 support
* Tue Oct  8 2024 Marcus Rueckert <mrueckert@suse.de>
- update suse.patch:
  handle ERB.new for older ruby versions
* Tue Oct  8 2024 Marcus Rueckert <mrueckert@suse.de>
- update suse.patch and sync in ruby-common/gem_packages.spec.erb
* Mon Oct  7 2024 Marcus Rueckert <mrueckert@suse.de>
- remove gem2rpm.yml.documentation as it is now in the git tree and
  therefor part of the suse.patch
* Mon Oct  7 2024 Marcus Rueckert <mrueckert@suse.de>
- replaced all patches with suse.patch generated with
  update-suse-patch.sh
  0001-use-the-ID-from-os-release-to-use-the-proper-templat.patch
  0002-added-basic-config-file-support-to-gem2rpm-in-yaml-f.patch
  0003-new-opensuse-templates.-they-require-the-config-file.patch
  0004-added-example-gem2rpm.yml.patch
  0005-properly-shorten-description-and-summary.patch
  0006-Preserve-the-license-header-found-in-the-output-file.patch
  0007-fixes-for-the-opensuse-template.patch
  0008-do-not-use-not-.-not-supported-on-1.8-e.g.patch
  0009-No-longer-require-the-ruby-version-inside-the-subpac.patch
  0010-Try-to-load-rbconfigpackagingsupport-and-fail-gracef.patch
  0011-Add-support-for-scripts-pre-post-for-subpackages.patch
  0012-typo-in-gem2rpm.yml.documentation-custom_pkgs-instea.patch
  0013-Also-tag-LICENSE-MIT-as-docfile.patch
  0014-Refactor-into-multiple-lines.patch
  0015-Add-licence-to-the-list-of-license-files-as-well.patch
  0016-add-two-more-ways-to-express-changes.patch
  0017-.markdown-is-also-seen-in-the-wild.patch
  0018-Only-use-the-extensions-doc-dir-on-MRI-2.1.x.patch
  0019-Cleaner-solution-for-the-extensions-doc-dir.patch
  0020-Ruby-1.8-insists-on-the-for-the-parameter.patch
  0021-Fix-company-name-in-copyright-header.patch
  0022-add-the-touch-for-build-compare-to-the-template.patch
  0023-Also-tag-APACHE-LICENSE-2.0-as-docfile.patch
  0024-add-ability-to-provide-alternative-main-Source.patch
  0025-allow-running-commands-after-patching.patch
  0026-use-https-instead-of-http-for-rubygems.org.patch
  0027-quote-version_suffix-in-gem2rpm.yml.documentation-to.patch
  0028-add-binary_map-support.patch
  0029-Use-or-for-the-conditions-instead-of-and.patch
  0030-gem_package.spec.erb-sync-with-ruby-common.patch
  0031-use-template-opensuse-on-openSUSE-Tumbleweed-where-e.patch
  0032-Replace-no-rdoc-no-ri-with-no-document.patch
  0033-Use-File.exist-instead-of-File.exists-which-was-remo.patch
  0034-plugin-dir.patch
  0035-fix-patch-syntax.patch
  template_loader.patch
* Fri Feb 23 2024 Marcus Rueckert <mrueckert@suse.de>
- Added 0034-plugin-dir.patch
  - also own the new gem plugin dir
- Added 0035-fix-patch-syntax.patch:
  Fix patch syntax for the upcoming rpm 4.20
* Mon Dec 25 2023 Marcus Rueckert <mrueckert@suse.de>
- Update the ruby ABI version in the 3.3.0 paths to the final
  string.
* Thu Sep 14 2023 Marcus Rueckert <mrueckert@suse.de>
- enable building for ruby 3.3
* Mon May  8 2023 Software System <opensuse@wolke7.net>
- add BuildRequires: ruby-common >= 3.2
  This version is required to rebuild the package. The older
  ruby-common is no longer sufficient.
* Fri Feb  3 2023 Marcus Rueckert <mrueckert@suse.de>
- replace the old options to disable docs with the modern -N
* Sun Dec 25 2022 Marcus Rueckert <mrueckert@suse.de>
- ruby 3.2.0 final has a normal ABI version again
* Fri Dec  9 2022 Martin Vidner <mvidner@suse.com>
- Use git format-patch instead, fixing one more exists? occurrence
  A    0033-Use-File.exist-instead-of-File.exists-which-was-remo.patch
- Note 0004-added-example-gem2rpm.yml.patch has the Rakefile hunk removed
* Mon Dec  5 2022 Martin Vidner <mvidner@suse.com>
- Edit patches to use File.exist? instead of File.exists? which was
  removed in Ruby 3.2
* Thu Nov 17 2022 Marcus Rueckert <mrueckert@suse.de>
- Fix filelist for 3.2.0
* Fri Nov 11 2022 Marcus Rueckert <mrueckert@suse.de>
- added support for 3.2.0
* Sun Dec 26 2021 Marcus Rueckert <mrueckert@suse.de>
- added support for 3.1.0
* Mon Sep 28 2020 Marcus Rueckert <mrueckert@suse.de>
- added support for 3.0.0
* Sun Jun 23 2019 Marcus Rueckert <mrueckert@suse.de>
- build without gem docs
* Sun Jun 23 2019 Marcus Rueckert <mrueckert@suse.de>
- added support for 2.7.0
* Sat Feb 23 2019 Stephan Kulow <coolo@suse.com>
- Update from git. Add:
  A    0027-quote-version_suffix-in-gem2rpm.yml.documentation-to.patch
  A    0028-add-binary_map-support.patch
  A    0029-Use-or-for-the-conditions-instead-of-and.patch
  A    0030-gem_package.spec.erb-sync-with-ruby-common.patch
  A    0031-use-template-opensuse-on-openSUSE-Tumbleweed-where-e.patch
  A    0032-Replace-no-rdoc-no-ri-with-no-document.patch
  And refresh all others
  Remove:
  D    binary_map.patch
  D    enhances.patch
* Mon Feb  4 2019 Jan Engelhardt <jengelh@inai.de>
- Use less strict PreReq replacements.
* Fri Jan 18 2019 Marcus Rueckert <mrueckert@suse.de>
- [42.3/sle12] disable ruby 2.3 and 2.4 so we can enable 2.6
* Fri Jun 29 2018 mrueckert@suse.de
- add ruby 2.6 support
* Fri Jun 15 2018 mrueckert@suse.de
- enhances.patch is a WIP but we add it to the filelist for the
  source validator
* Wed Jun  6 2018 mrueckert@suse.de
- added binary_map.patch:
  add way to avoid conflicts with non rubygems packages in /usr/bin
- added template_loader.patch (boo#1092585)
* Wed Nov  8 2017 mrueckert@suse.de
- disable 2.2 on suse_version 1315
* Wed Aug  9 2017 mrueckert@suse.de
- add ruby 2.5 support
* Thu Nov 10 2016 mrueckert@suse.de
- fix gem2rpm --fetch: prefer https for accessing rubygems.org
  (bnc #963710)
  adds 0026-use-https-instead-of-http-for-rubygems.org.patch
* Thu Nov 10 2016 mrueckert@suse.de
- added support for 2.4.0
* Thu Nov 10 2016 mrueckert@suse.de
- dropped all patches and replaced them with git format-patch
  series:
  - modified:
    0001-use-the-ID-from-os-release-to-use-the-proper-templat.patch
    0002-added-basic-config-file-support-to-gem2rpm-in-yaml-f.patch
    0003-new-opensuse-templates.-they-require-the-config-file.patch
    0004-added-example-gem2rpm.yml.patch
    0005-properly-shorten-description-and-summary.patch
    0006-Preserve-the-license-header-found-in-the-output-file.patch
    0007-fixes-for-the-opensuse-template.patch
    0008-do-not-use-not-.-not-supported-on-1.8-e.g.patch
    0009-No-longer-require-the-ruby-version-inside-the-subpac.patch
    0010-Try-to-load-rbconfigpackagingsupport-and-fail-gracef.patch
    0011-Add-support-for-scripts-pre-post-for-subpackages.patch
    0012-typo-in-gem2rpm.yml.documentation-custom_pkgs-instea.patch
    0013-Also-tag-LICENSE-MIT-as-docfile.patch
    0014-Refactor-into-multiple-lines.patch
    0015-Add-licence-to-the-list-of-license-files-as-well.patch
    0016-add-two-more-ways-to-express-changes.patch
  - dropped:
    0017-touch-unpacked-sources.patch
    0001-Also-tag-APACHE-LICENSE-2.0-as-docfile.patch
  - newly added:
    0017-.markdown-is-also-seen-in-the-wild.patch
    0018-Only-use-the-extensions-doc-dir-on-MRI-2.1.x.patch
    0019-Cleaner-solution-for-the-extensions-doc-dir.patch
    0020-Ruby-1.8-insists-on-the-for-the-parameter.patch
    0021-Fix-company-name-in-copyright-header.patch
    0022-add-the-touch-for-build-compare-to-the-template.patch
    0023-Also-tag-APACHE-LICENSE-2.0-as-docfile.patch
    0024-add-ability-to-provide-alternative-main-Source.patch
    0025-allow-running-commands-after-patching.patch
- added :post_patch hook to run commands before we rebuild the gem
  used by libv8
* Mon Jul 18 2016 tbechtold@suse.com
- add 0001-Also-tag-APACHE-LICENSE-2.0-as-docfile.patch
* Wed Apr  6 2016 coolo@suse.com
- add 0017-touch-unpacked-sources.patch to please build-compare
* Wed Nov 11 2015 mrueckert@suse.de
- remove the rubinius 2.2 support
- add support for rubinius 2.5 and ruby 2.3
* Thu Apr 16 2015 mrueckert@suse.de
- update
  0003-new-opensuse-templates.-they-require-the-config-file.patch:
  Fix company name in copyright header
* Wed Feb 11 2015 coolo@suse.com
- more patches from git:
  A    0010-Try-to-load-rbconfigpackagingsupport-and-fail-gracef.patch
  A    0011-Add-support-for-scripts-pre-post-for-subpackages.patch
  A    0012-typo-in-gem2rpm.yml.documentation-custom_pkgs-instea.patch
  A    0013-Also-tag-LICENSE-MIT-as-docfile.patch
  A    0014-Refactor-into-multiple-lines.patch
  A    0015-Add-licence-to-the-list-of-license-files-as-well.patch
  A    0016-add-two-more-ways-to-express-changes.patch
* Tue Oct 21 2014 mrueckert@suse.de
- added 0009-No-longer-require-the-ruby-version-inside-the-subpac.patch
  No longer require the ruby version inside the subpackage
  With the buildrequires we already make sure that the package is
  only built if we find a recent enough ABI. then the normal
  $interpreter(abi) requires generated by rpm is enough
* Tue Oct 21 2014 mrueckert@suse.de
- refreshed patch series to match the git again:
  M 0001-use-the-ID-from-os-release-to-use-the-proper-templat.patch
  M 0002-added-basic-config-file-support-to-gem2rpm-in-yaml-f.patch
  A 0003-new-opensuse-templates.-they-require-the-config-file.patch
  A 0004-added-example-gem2rpm.yml.patch
  A 0005-properly-shorten-description-and-summary.patch
  A 0006-Preserve-the-license-header-found-in-the-output-file.patch
  A 0007-fixes-for-the-opensuse-template.patch
  A 0008-do-not-use-not-.-not-supported-on-1.8-e.g.patch
  D 0003-sle-12-templates.-they-require-the-config-file-suppo.patch
  D 0004-openSUSE-template-fixes.patch
  D 0005-added-example-gem2rpm.yml.patch
  D 0006-properly-shorten-description-and-summary.patch
  D 0007-Preserve-the-license-header-found-in-the-output-file.patch
  D 0008-dont-allow-suffixes-with-just-a-plain-number.-prefix.patch
  D 0009-rubinius-has-no-extensions-docdir.patch
  D 0010-switch-to-new-packaging-scheme-by-default.patch
  D 0011-fixes-for-the-opensuse-template.patch
- new patch for fixing usage of not() which breaks on 1.8
* Wed Oct 15 2014 coolo@suse.com
- add 0011-fixes-for-the-opensuse-template.patch to survive
  format_spec formatting
* Mon Oct 13 2014 mrueckert@suse.de
- added 0009-rubinius-has-no-extensions-docdir.patch
  special casing for rubinius
- added 0010-switch-to-new-packaging-scheme-by-default.patch
  move to new packaging templates by default
* Mon Sep 22 2014 mrueckert@suse.de
- added ruby 1.9 support
* Wed Sep 17 2014 mrueckert@suse.de
- added ruby 1.8 support
- also guarded the 2.1 part
* Wed Sep 17 2014 mrueckert@suse.de
- added 0008-dont-allow-suffixes-with-just-a-plain-number.-prefix.patch
  Dont allow an suffix with just a plain number. prefix it with
  ruby.
* Wed Sep 17 2014 mrueckert@suse.de
- added ruby 2.0 support
* Mon Sep  8 2014 mrueckert@suse.de
- changed rubinius macro
* Fri Sep  5 2014 mrueckert@suse.de
- for easier bootstrapping dont use gem2rpm here for now.
* Thu Sep  4 2014 mrueckert@suse.de
- make it easier to enable rbx and ruby 2.2 support
* Wed Sep  3 2014 mrueckert@suse.de
- added support for building for rbx
* Mon Jul 28 2014 mrueckert@suse.de
- really install the templates as docs
* Thu Jul 24 2014 mrueckert@suse.de
- update to 0.10.1
  - Migrate test suite to Minitest 5.x.
  - Move gem binary extension and gem.build_complete file.
  - Merge pull request #31 from axilleas/add_check_macro
  - Add %%check macro, fix typos
  - Remove Requires/Provides which are now autogenerated.
  - Simplify binary extensions installation according to the new
    guidelines.
  - Clone new template for F21 and above. Rename the old one.
  - "cp -a" implies -p.
  - Better open mode handling.
  - Test always against rawhide template.
  - List development dependencies as BuildRequires.
  - Cache rendered template in tests.
  - Prevent dangling symlink in -debuginfo.
  - Ignore release file encoding with older Ruby (fixes #23).
  - Fix generating SRPM.
  - Add description dot test case.
  - Add description ending dot in #description method.
  - Avoid 'method is redefined' warning.
  - Test against current template.
  - Merge pull request #25 from xsuchy/pull-req-dot
  - description should end with dot
  - Merge pull request #24 from strzibny/master
  - Escape %% in comment
- rebased gem2rpm-change-default-template.diff, new name:
  0001-use-the-ID-from-os-release-to-use-the-proper-templat.patch
- rebased gem2rpm-0.9.2_config_file_support.patch, new name
  0002-added-basic-config-file-support-to-gem2rpm-in-yaml-f.patch
- rebased gem2rpm-0.9.2_sles12_template.patch, new name:
  0003-sle-12-templates.-they-require-the-config-file-suppo.patch
- rebased and splitted gem2rpm-fix-opensuse-template.diff, new
  name:
  0004-openSUSE-template-fixes.patch
  0005-added-example-gem2rpm.yml.patch
  0006-properly-shorten-description-and-summary.patch
  0007-Preserve-the-license-header-found-in-the-output-file.patch
* Wed Jul 23 2014 mrueckert@suse.de
- make sure the sle12 template is also installed
* Mon Jul 21 2014 mrueckert@suse.de
- added gem2rpm_bootstrap conditional:
  If this is set to true, the hardcoded subpackage/files sections
  are used. Otherwise it will use the normal gem2rpm based solution
- renamed gem2rpm.yml to gem2rpm.yml.documentation:
  this is just documentation and not the gem2rpm.yml that gem2rpm
  should pick up.
* Mon Jul 21 2014 mrueckert@suse.de
- added gem2rpm-0.9.2_sles12_template.patch:
  initial template for sle12 ruby packaging
- only build for 2.1 for now
* Tue Jul 15 2014 mrueckert@suse.de
- added gem2rpm.yml and install it to the installed documentation
* Tue Jul 15 2014 mrueckert@suse.de
- sles 12 template
  - allow changing the master package name with config[:name]
    This is mostly useful if you want the actual main package to
    have real content after building. all the subpackages will
    ignore config[:name] and still use the gem name.
* Tue Jul 15 2014 mrueckert@suse.de
- sles 12 template
  - add version suffix to the "spec file for ..." line
  - move the preamble up so we can actually use
    %%define rb_build_versions ...
  - config[:disable_automatic_rdoc_dep] to disable adding automatic
    rdoc dependency. This is mostly needed for building rdoc itself
    and avoiding a bootstrap cycle.
  - actually print the patch name in the preamble
  - the scripts entry in gem2rpm.yml can now be a hash or a string.
* Tue Jul 15 2014 mrueckert@suse.de
- sles 12 template
  - no longer print the gem2rpm.yml warning when the config is empty
  - add back mod_version_suffix to the spec file
    (needed for gem_install)
- converted buildrequires for ruby and ruby-devel to the macros so
  we can easily pull multiple ruby versions and also easily limit
  the ruby versions
- always buildrequire gem2rpm in generated spec files. It is the
  only clean way to solve the "have choive for rubygem(gem2rpm)"
  and still maintaining the multiversion ability
- handle config[:disable_docs] and pass --no-rdoc --no-ri to
  gem_install in that case. (mostly a workaround for the rdoc bug
  with the fastthread gem)
- added support to specify the content of the %%check section.
* Fri Jul 11 2014 mrueckert@suse.de
- if the config is nil, set it to an empty hash. this allows for
  less noisy template files.
- more updates for the sle 12 template.
* Thu Jul 10 2014 mrueckert@suse.de
- added new tag :sources in the yaml file to track additional
  sources. this makde the next change much easier.
- make sure the config file that is passed to gem2rpm is also
  appended to the sources list automatically.
- added template for sles12 (gem2rpm-0.9.2_sles12_template.patch)
* Thu Jul 10 2014 mrueckert@suse.de
- added gem2rpm-0.9.2_config_file_support.patch:
  added basic config file support to gem2rpm in yaml format. there
  is no validation as it is basically a hash where certain keys
  are picked up by our templates.
- added quilt series file to the sources list
- dropped empty doc package
* Thu Jun 26 2014 mrueckert@suse.de
- update rpm macros requires to 5
* Wed Jun 25 2014 mrueckert@suse.de
- fix filelist for multi ruby packaging
* Wed Jun 25 2014 mrueckert@suse.de
- add ruby 2.2 support
* Tue Jun 24 2014 mrueckert@suse.de
- added BuildIgnore for rubygem(gem2rpm), otherwise we can not
  bootstrap a new ruby version. this package will need the
  subpackages for a new ruby version to be created manually.
* Wed Jun 18 2014 mrueckert@suse.de
- fixed paths in the u-a scriptlets
* Wed Jun 18 2014 mrueckert@suse.de
- no longer provide gem2rpm-opensuse
- use new style packaging but the hardcoded version
* Thu Feb  6 2014 coolo@suse.com
- buildrequire ruby-devel for extensions
* Mon Jan 13 2014 coolo@suse.com
- switch to the macros Klaus wrote
- modified patches:
  * gem2rpm-fix-opensuse-template.diff
* Wed Jun 26 2013 coolo@suse.com
- doing update-alternatives correctly after reading
  http://en.opensuse.org/openSUSE:Packaging_Multiple_Version_guidelines
* Wed Jun 26 2013 coolo@suse.com
- avoid --force in update-alternatives as SLE11 does not have that ;(
* Mon Jun 10 2013 coolo@suse.com
- make sure license.txt is also symlinked
* Sat Jun  8 2013 coolo@suse.com
- integrate more of the version into the mod_weight to give
  an easier job to update-alternatives
- use --force in update-alternatives to replace (old) binaries
* Sat May 25 2013 coolo@suse.com
- include changelog and history files too
* Tue May  7 2013 coolo@suse.com
- more license files
* Thu May  2 2013 coolo@suse.com
- ciaran wants to see the license files mentioned in %%docdir, so create
  symlinks
* Sun Apr 28 2013 coolo@suse.com
- support ruby 2.0
* Sat Apr 27 2013 coolo@suse.com
- update to 0.9.2 - no changelog
* Mon Apr 22 2013 mrueckert@suse.de
- fix redirection in gem2rpm-opensuse
* Mon Mar 18 2013 coolo@suse.com
- update to 0.8.4 - fixes for fedora 18
- use url for sources
* Mon Aug  6 2012 coolo@suse.com
- buildrequire rdoc if there are options (I just picked 3.10 as
  minimum, which is one higher than what ruby 1.9.1 offers in itself)
* Wed Aug  1 2012 coolo@suse.com
- shorten the summary
* Mon Jul 30 2012 cfarrell@suse.com
- license update: GPL-2.0+
  See data/LICENSE
* Fri Jul 27 2012 coolo@suse.com
- do not use %%gem_unpack by default
* Fri Jul 27 2012 coolo@suse.com
- do not put out empty URLs
* Thu Jul 26 2012 coolo@suse.com
- fix OS detection on SLE11
* Thu Jul 26 2012 coolo@suse.com
- no longer provide stuff for older distributions, we rely on patched
  rpms
* Wed Jul 25 2012 coolo@suse.com
- do not add buildrequires, but install with -f
* Tue Jul 24 2012 coolo@suse.com
- cleanup the opensuse template
* Tue Jul 24 2012 coolo@suse.com
- update to 0.8.1, major cleanup and base on new macros
* Wed Apr  4 2012 coolo@suse.com
- small cleanup
* Wed Dec  7 2011 jreidinger@suse.com
- fix requirements, as package need to run json parser
* Wed Mar 23 2011 mrueckert@suse.de
- dont check if spec.license responds_to each. strings have that
  method too. check for join
- minor template cleanup
* Tue Mar 22 2011 jreidinger@novell.com
- Don't have hardcoded license. Try to extract it from specfile or
  if it fail force user to manually check license. It avoids
  problems with wrong license for rubygems
* Fri Feb 18 2011 mrueckert@suse.de
- remove license tag from doc/testsuite package
* Mon Jan 31 2011 mrueckert@suse.de
- small template clean up
* Thu Jan 20 2011 mrueckert@suse.de
- remove version from header comment
- calculate the year on run
* Mon Jan 17 2011 mvidner@suse.cz
- Updated openSUSE template to produce *- doc and *-testsuite subpackages.
  http://lists.opensuse.org/opensuse-ruby/2010-12/msg00001.html
* Thu Dec  9 2010 chris@computersalat.de
- update template
  o # Copyright (c) 2010
* Wed Jun  9 2010 mrueckert@suse.de
- fix typo in template:
  "requirements" is not "requirement".
* Wed Jun  9 2010 mrueckert@suse.de
- fix deprecation warning in template with newer versions of rubygems:
  version_requirements is now called requirements
* Tue May 25 2010 mrueckert@suse.de
- use rubygems_requires macro instead of repeating the
  [#]if-conditional in every package
* Tue May 25 2010 mrueckert@suse.de
- use requires_eq/requires_ge instead of hardcoding the rubygems
  version during spec generation
* Tue Mar  2 2010 prusnak@suse.cz
- use default URL when none is specified in gem (default-url.patch)
* Fri Jan 22 2010 prusnak@suse.cz
- fix version transform (fix-spec-versions.patch)
* Sat Nov 14 2009 mrueckert@suse.de
- ignore development type requires of gems
* Fri Mar 27 2009 mrueckert@suse.de
- fix opensuse template
* Fri Mar 27 2009 mrueckert@suse.de
- initial package
